==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Відновлюємо попередній стан системи. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Не вдалося відкотити.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Не вдалося оновити.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Не вдалося оновити: оновлення перервано.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Невдале оновлення: помилка DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Помилка оновлення: недостатньо місця на диску.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Ви справді хочете повернутися до резервної копії deepin %1 від %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Скасувати і перезавантажитися</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.21.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Відновлюємо попередній стан системи. Будь ласка, зачекайте…</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Не вдалося відкотити.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Не вдалося оновити.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Не вдалося оновити: оновлення перервано.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Невдале оновлення: помилка DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Помилка оновлення: недостатньо місця на диску.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Ви справді хочете повернутися до резервної копії deepin %1 від %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Скасувати і перезавантажитися</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
</TS>
